@@ -317,7 +317,7 @@ class ScientificRule(RegexRule):
             re.compile(r'^[+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?$'),
             False,
             message_template or
-            _('Required to be a valid number is scientific format.'))
+            _('Required to be a valid number in scientific format.'))
 
     def __call__(self, message_template):
         """ Let you customize message template.
@@ -330,17 +330,35 @@ class Base64Rule(RegexRule):
     """
     __slots__ = ()
 
-    def __init__(self, message_template=None):
+    def __init__(self, altchars='+/', message_template=None):
         super(Base64Rule, self).__init__(
-            re.compile(r'^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|'
-                       '[A-Za-z0-9+/]{3}=)?$'), False,
+            re.compile('^(?:[A-Za-z0-9%s]{4})*(?:[A-Za-z0-9%s]{2}==|'
+                       '[A-Za-z0-9%s]{3}=)?$' % ((altchars,) * 3)), False,
             message_template or
             _('Required to be a valid base64 string.'))
 
+    def __call__(self, message_template, altchars='+/'):
+        """ Let you customize message template.
+        """
+        return Base64Rule(altchars, message_template)
+
+
+class URLSafeBase64Rule(Base64Rule):
+    """ Ensures a valid base64 URL-safe string input using an alphabet,
+        which substitutes `-` instead of `+` and `_` instead of `/` in
+        the standard Base64 alphabet. The input can still contain `=`.
+    """
+    __slots__ = ()
+
+    def __init__(self, message_template=None):
+        super(URLSafeBase64Rule, self).__init__(
+            '-_', message_template or
+            _('Required to be a valid URL-safe base64 string.'))
+
     def __call__(self, message_template):
         """ Let you customize message template.
         """
-        return Base64Rule(message_template)
+        return URLSafeBase64Rule(message_template)
 
 
 class RangeRule(object):
@@ -716,7 +734,7 @@ class IntAdapterRule(AdapterRule):
 
 adapter = AdapterRule
 and_ = AndRule
-base64 = Base64Rule()
+base64 = standard_base64 = Base64Rule()
 compare = CompareRule
 email = EmailRule()
 ignore = IgnoreRule
@@ -731,15 +749,16 @@ range = RangeRule
 regex = RegexRule
 relative_date = RelativeDateDeltaRule
 relative_datetime = RelativeDateTimeDeltaRule
+relative_timestamp = RelativeUnixTimeDeltaRule
 relative_tzdate = RelativeTZDateDeltaRule
 relative_tzdatetime = RelativeTZDateTimeDeltaRule
 relative_unixtime = RelativeUnixTimeDeltaRule
-relative_timestamp = RelativeUnixTimeDeltaRule
 relative_utcdate = RelativeUTCDateDeltaRule
 relative_utcdatetime = RelativeUTCDateTimeDeltaRule
-relative_utcunixtime = RelativeUTCUnixTimeDeltaRule
 relative_utctimestamp = RelativeUTCUnixTimeDeltaRule
+relative_utcunixtime = RelativeUTCUnixTimeDeltaRule
 required = RequiredRule()
 scientific = ScientificRule()
 slug = SlugRule()
+urlsafe_base64 = URLSafeBase64Rule()
 value_predicate = must = ValuePredicateRule
